%% This function determines the expected welfare loss due to nominal rigidities
%  The inputs are the policy weights

function EWL_GDP = expected_welfareloss_nonlinear(psi,logz, eta, gamma, phi)


%% Level of epxected welfare loss under sticky prices 

% Monte Carlo simulation 
iteration = length(logz);
welfare_loss = zeros(iteration,1);
exitflag = zeros(iteration,1);
for i=1:iteration
    
    % caluclating welfare loss given the shocks (and policy)
    % exitflag=1 if solving for equilibrium was successful
    [welfare_loss(i) , exitflag(i)]= expost_welfareloss_nonlinear(logz(:,i), psi, eta, gamma, phi);
end

expected_welfareloss = mean(welfare_loss(exitflag(:)==1));



%% Expected welfare loss measured as a fraction of steady-state consumption

if gamma ~= 1
    EWL_GDP = 1 - (1 - (1-gamma)*expected_welfareloss)^(1/(1-gamma));
end

if gamma ==1
    EWL_GDP = 1 -exp(-expected_welfareloss);
end



end






