%% This function calculates the sectoral weights under optimal policy (based on Theorem 2)

%  The inputs are preference parameters and the elasticity of substitution.
%  The output is the optimal policy characterized in equation (39) of the paper.

function psi_star = optimalpolicy(eta, gamma, phi)


global A n alpha theta L Domar beta

rho = inv(eye(n) - A*diag(phi)) * alpha;    % degree of upstream flexibility
rho_0 = beta' * diag(phi) * rho;

% Various terms of optimal policy
psi_og = 1./phi .* (1-phi) .* Domar * (1-rho_0)/(gamma+ 1/eta);
psi_within = theta .*  (1 - phi) .* Domar .* rho;
psi_across = (inv(diag(phi)) - eye(n)) * (rho_0 * Domar - diag(rho)*Domar + L' * (eye(n) - diag(phi))*diag(Domar) * rho );

% Optimal Policy
psi_star = psi_og + psi_within + psi_across;

% Renormalize so that the weights of optimal policy add up to 1
psi_star = psi_star/(sum(psi_star));

end
