%% This function calculates the expected welfare loss of a policy to a second-order approximation. 
%  The expression is based on Proposition 6

function [Delta,LossOG,LossAcross,LossWithin] = welfarelossQuadratic(psi, eta , gamma , phi)

global A n theta alpha Sigmaz L Domar beta;

% determining the weights of the policy's wage representation (based on Lemma B.1)
kappa = (psi'* inv(eye(n) - diag(phi)*A) * diag(phi))./(psi'*inv(eye(n) - diag(phi)*A)*diag(phi)*alpha);
kappa = kappa';


% auxilary matrices
Q = inv(eye(n) - diag(phi)*A) * (eye(n) - diag(phi));
ExpEE = Q * (L - ones(n,1)*kappa') * Sigmaz * (L' - kappa*ones(1,n)) * Q';
B = inv(eye(n) - diag(phi)*A) * diag(phi) * (eye(n) - A) * (L - ones(n,1)*kappa');

% Components of the welfare loss
LossOG = 1/2 * 1/(gamma + 1/eta) * beta' * ExpEE * beta;
LossAcross = 1/2 * (Domar' * diag(ExpEE) - Domar' * diag(A*ExpEE*A') - beta' * ExpEE * beta);
LossWithin = 1/2 * (theta * Domar' * (diag(1./phi) - eye(n)) * diag(B*Sigmaz*B'));

% Total welfare loss
Delta = LossOG + LossAcross + LossWithin;

end


